@@ -100,7 +100,7 @@
  * not have it). In that case, transparently replace all
  * occurences of that builtin with just the condition:
  */
-#ifndef HAVE_BUILTIN_EXPECT
+#ifndef _HAVE_BUILTIN_EXPECT
 #define __builtin_expect(cond, exp) (cond)
 #endif
 
@@ -258,7 +258,7 @@
 #define	__section(x)	__attribute__((__section__(x)))
 #endif
 
-#ifdef HAVE_ALLOC_SIZE
+#ifdef _HAVE_ALLOC_SIZE
 #define	__alloc_size(x)	__attribute__((__alloc_size__(x)))
 #define	__alloc_size2(n, x)	__attribute__((__alloc_size__(n, x)))
 #else
@@ -386,17 +386,21 @@
 #define	__pure
 #endif
 
+#ifndef __always_inline
 #if __GNUC_PREREQ__(3, 1) || (defined(__INTEL_COMPILER) && __INTEL_COMPILER >= 800)
 #define	__always_inline	__inline__ __attribute__((__always_inline__))
 #else
 #define	__always_inline
 #endif
+#endif
 
+#ifndef __noinline
 #if __GNUC_PREREQ__(3, 1)
 #define	__noinline	__attribute__ ((__noinline__))
 #else
 #define	__noinline
 #endif
+#endif
 
 #if defined(__clang__) && defined(__nonnull)
 /* Clang has a builtin macro __nonnull for the _Nonnull qualifier */
@@ -554,7 +558,7 @@
 #endif
 
 #if defined(__GNUC__) || defined(__INTEL_COMPILER)
-#if !defined(__INTEL_COMPILER) && defined(HAVE_ALIAS_ATTRIBUTE)
+#if !defined(__INTEL_COMPILER) && defined(_HAVE_ALIAS_ATTRIBUTE)
 #define	__strong_reference(sym,aliassym)	\
 	extern __typeof (sym) aliassym __attribute__ ((__alias__ (#sym)))
 #endif
