@@ -168,9 +168,7 @@ hash3(keyarg, len)
 
 /* Hash function from Chris Torek. */
 static __uint32_t
-hash4(keyarg, len)
-	const void *keyarg;
-	size_t len;
+hash4(const void *keyarg, size_t len)
 {
 	const u_char *key;
 	__uint32_t h;
