@@ -44,7 +44,7 @@
  */
 
 #include <sys/reent.h>
-#include <sys/types.h>
+#include <sys/_types.h>
 
 _BEGIN_STD_C
 
@@ -62,6 +62,16 @@ typedef _fpos64_t fpos64_t;
 #endif
 #endif /* !__CYGWIN__ */
 
+#ifndef _OFF_T_DECLARED
+typedef __off_t off_t;
+#define	_OFF_T_DECLARED
+#endif
+
+#ifndef _SSIZE_T_DECLARED
+typedef _ssize_t ssize_t;
+#define	_SSIZE_T_DECLARED
+#endif
+
 #include <sys/stdio.h>
 
 #define	__SLBF	0x0001		/* line buffered */
@@ -208,13 +218,13 @@ int	puts (const char *);
 int	ungetc (int, FILE *);
 size_t	fread (void *__restrict, size_t _size, size_t _n, FILE *__restrict);
 size_t	fwrite (const void *__restrict , size_t _size, size_t _n, FILE *);
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 int	fgetpos (FILE *, _fpos_t *);
 #else
 int	fgetpos (FILE *__restrict, fpos_t *__restrict);
 #endif
 int	fseek (FILE *, long, int);
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 int	fsetpos (FILE *, const _fpos_t *);
 #else
 int	fsetpos (FILE *, const fpos_t *);
@@ -231,12 +241,12 @@ int	sprintf (char *__restrict, const char *__restrict, ...)
                _ATTRIBUTE ((__format__ (__printf__, 2, 3)));
 int	remove (const char *);
 int	rename (const char *, const char *);
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 int	_rename (const char *, const char *);
 #endif
 #endif
 #if __LARGEFILE_VISIBLE || __POSIX_VISIBLE >= 200112
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 int	fseeko (FILE *, _off_t, int);
 _off_t	ftello (FILE *);
 #else
@@ -402,7 +412,7 @@ int	_fgetc_r (struct _reent *, FILE *);
 int	_fgetc_unlocked_r (struct _reent *, FILE *);
 char *  _fgets_r (struct _reent *, char *__restrict, int, FILE *__restrict);
 char *  _fgets_unlocked_r (struct _reent *, char *__restrict, int, FILE *__restrict);
-#ifdef _COMPILING_NEWLIB
+#ifdef _LIBC
 int	_fgetpos_r (struct _reent *, FILE *__restrict, _fpos_t *__restrict);
 int	_fsetpos_r (struct _reent *, FILE *, const _fpos_t *);
 #else
@@ -538,7 +548,7 @@ int	fputs_unlocked (const char *__restrict, FILE *__restrict);
 #endif
 
 #ifdef __LARGE64_FILES
-#if !defined(__CYGWIN__) || defined(_COMPILING_NEWLIB)
+#if !defined(__CYGWIN__) || defined(_LIBC)
 FILE *	fdopen64 (int, const char *);
 FILE *  fopen64 (const char *, const char *);
 FILE *  freopen64 (const char *, const char *, FILE *);
