@@ -41,6 +41,9 @@
 #include <string.h>
 #include <errno.h>
 
+extern struct timeval __semihost_write_time _ATTRIBUTE((__weak__));
+int gettimeofday(struct timeval *restrict tv, void *restrict tz) _ATTRIBUTE((__weak__));
+
 _READ_WRITE_RETURN_TYPE
 write(int fd, const void *buf, size_t count)
 {
@@ -49,6 +52,9 @@ write(int fd, const void *buf, size_t count)
 #endif
 	uintptr_t ret = sys_semihost_write(fd, buf, count);
 
+        if (&__semihost_write_time && gettimeofday)
+            gettimeofday(&__semihost_write_time, NULL);
+
 	_READ_WRITE_RETURN_TYPE put = (_READ_WRITE_RETURN_TYPE) count - (_READ_WRITE_RETURN_TYPE) ret;
 	return put;
 }
